huggingface_quick_clean: Run some fast text normalisation steps for output to...

View source: R/huggingface_quick_clean.R

huggingface_quick_cleanR Documentation

Run some fast text normalisation steps for output to Huggingface

Description

Run some fast text normalisation steps for output to Huggingface

Usage

huggingface_quick_clean(df, text_var)

Arguments

df

Data Frame or Tibble object

text_var

Name of the text variable

Value

Tibble with two columns


jpcompartir/JPackage documentation built on March 20, 2023, 4 a.m.